@@ -23,18 +23,19 @@ import (
 	imageregistryv1 "github.com/openshift/api/imageregistry/v1"
 	operatorapi "github.com/openshift/api/operator/v1"
 
-	"github.com/openshift/cluster-image-registry-operator/defaults"
 	regopclient "github.com/openshift/cluster-image-registry-operator/pkg/client"
+	"github.com/openshift/cluster-image-registry-operator/pkg/defaults"
 	"github.com/openshift/cluster-image-registry-operator/pkg/envvar"
 	"github.com/openshift/cluster-image-registry-operator/pkg/storage/util"
-	"github.com/openshift/cluster-image-registry-operator/version"
+	"github.com/openshift/cluster-image-registry-operator/pkg/version"
 )
 
 type S3 struct {
-	AccessKey string
-	SecretKey string
-	Bucket    string
-	Region    string
+	AccessKey      string
+	SecretKey      string
+	Bucket         string
+	Region         string
+	RegionEndpoint string
 }
 
 type driver struct {
@@ -64,6 +65,13 @@ func GetConfig(listers *regopclient.Listers) (*S3, error) {
 
 	if infra.Status.PlatformStatus != nil && infra.Status.PlatformStatus.Type == configapiv1.AWSPlatformType {
 		cfg.Region = infra.Status.PlatformStatus.AWS.Region
+
+		for _, ep := range infra.Status.PlatformStatus.AWS.ServiceEndpoints {
+			if ep.Name == "s3" {
+				cfg.RegionEndpoint = ep.URL
+				break
+			}
+		}
 	}
 
 	// Look for a user defined secret to get the AWS credentials from first
@@ -97,29 +105,41 @@ func GetConfig(listers *regopclient.Listers) (*S3, error) {
 			cfg.SecretKey = string(v)
 		} else {
 			return nil, fmt.Errorf("secret %q does not contain required key \"REGISTRY_STORAGE_S3_SECRETKEY\"", fmt.Sprintf("%s/%s", defaults.ImageRegistryOperatorNamespace, defaults.ImageRegistryPrivateConfigurationUser))
-
 		}
 	}
 
 	return cfg, nil
 }
 
+func (d *driver) updateConfigAndGetCredentials() (accessKey, secretKey string, err error) {
+	cfg, err := GetConfig(d.Listers)
+	if err != nil {
+		return "", "", err
+	}
+
+	if len(d.Config.Region) == 0 && len(d.Config.RegionEndpoint) == 0 {
+		d.Config.Region = cfg.Region
+		d.Config.RegionEndpoint = cfg.RegionEndpoint
+		if len(cfg.RegionEndpoint) != 0 {
+			d.Config.VirtualHostedStyle = true
+		}
+	}
+
+	return cfg.AccessKey, cfg.SecretKey, nil
+}
+
 // getS3Service returns a client that allows us to interact
 // with the aws S3 service
 func (d *driver) getS3Service() (*s3.S3, error) {
-	cfg, err := GetConfig(d.Listers)
+	accessKey, secretKey, err := d.updateConfigAndGetCredentials()
 	if err != nil {
 		return nil, err
 	}
 
-	if len(d.Config.Region) == 0 {
-		d.Config.Region = cfg.Region
-	}
-
 	// A custom HTTPClient is used here since the default HTTPClients ProxyFromEnvironment
 	// uses a cache which won't let us update the proxy env vars
 	awsConfig := &aws.Config{
-		Credentials: credentials.NewStaticCredentials(cfg.AccessKey, cfg.SecretKey, ""),
+		Credentials: credentials.NewStaticCredentials(accessKey, secretKey, ""),
 		Region:      &d.Config.Region,
 		HTTPClient: &http.Client{
 			Transport: &http.Transport{
@@ -131,7 +151,9 @@ func (d *driver) getS3Service() (*s3.S3, error) {
 	}
 	awsConfig.WithUseDualStack(true)
 	if d.Config.RegionEndpoint != "" {
-		awsConfig.WithS3ForcePathStyle(true)
+		if !d.Config.VirtualHostedStyle {
+			awsConfig.WithS3ForcePathStyle(true)
+		}
 		awsConfig.WithEndpoint(d.Config.RegionEndpoint)
 	}
 	sess, err := session.NewSession(awsConfig)
@@ -144,7 +166,6 @@ func (d *driver) getS3Service() (*s3.S3, error) {
 	})
 
 	return s3.New(sess), nil
-
 }
 
 func isBucketNotFound(err interface{}) bool {
@@ -172,7 +193,7 @@ func isBucketNotFound(err interface{}) bool {
 // ConfigEnv configures the environment variables that will be
 // used in the image registry deployment
 func (d *driver) ConfigEnv() (envs envvar.List, err error) {
-	cfg, err := GetConfig(d.Listers)
+	accessKey, secretKey, err := d.updateConfigAndGetCredentials()
 	if err != nil {
 		return nil, err
 	}
@@ -190,9 +211,10 @@ func (d *driver) ConfigEnv() (envs envvar.List, err error) {
 		envvar.EnvVar{Name: "REGISTRY_STORAGE_S3_BUCKET", Value: d.Config.Bucket},
 		envvar.EnvVar{Name: "REGISTRY_STORAGE_S3_REGION", Value: d.Config.Region},
 		envvar.EnvVar{Name: "REGISTRY_STORAGE_S3_ENCRYPT", Value: d.Config.Encrypt},
+		envvar.EnvVar{Name: "REGISTRY_STORAGE_S3_VIRTUALHOSTEDSTYLE", Value: d.Config.VirtualHostedStyle},
 		envvar.EnvVar{Name: "REGISTRY_STORAGE_S3_USEDUALSTACK", Value: true},
-		envvar.EnvVar{Name: "REGISTRY_STORAGE_S3_ACCESSKEY", Value: cfg.AccessKey, Secret: true},
-		envvar.EnvVar{Name: "REGISTRY_STORAGE_S3_SECRETKEY", Value: cfg.SecretKey, Secret: true},
+		envvar.EnvVar{Name: "REGISTRY_STORAGE_S3_ACCESSKEY", Value: accessKey, Secret: true},
+		envvar.EnvVar{Name: "REGISTRY_STORAGE_S3_SECRETKEY", Value: secretKey, Secret: true},
 	)
 
 	if d.Config.CloudFront != nil {
