@@ -22,8 +22,8 @@ import (
 	imageregistryv1 "github.com/openshift/api/imageregistry/v1"
 	operatorapi "github.com/openshift/api/operator/v1"
 
-	"github.com/openshift/cluster-image-registry-operator/defaults"
 	regopclient "github.com/openshift/cluster-image-registry-operator/pkg/client"
+	"github.com/openshift/cluster-image-registry-operator/pkg/defaults"
 	"github.com/openshift/cluster-image-registry-operator/pkg/envvar"
 	"github.com/openshift/cluster-image-registry-operator/pkg/storage/util"
 )
@@ -235,16 +235,14 @@ func (d *driver) getSwiftClient() (*gophercloud.ServiceClient, error) {
 
 	var client *gophercloud.ServiceClient
 	client, err = openstack.NewContainerV1(provider, endpointOpts)
-	if err != nil {
-		if _, ok := err.(*gophercloud.ErrEndpointNotFound); ok {
-			endpointOpts.Type = "object-store"
-			client, err = openstack.NewContainerV1(provider, endpointOpts)
-			if err != nil {
-				return nil, err
-			}
-		} else {
+	if _, ok := err.(*gophercloud.ErrEndpointNotFound); ok {
+		endpointOpts.Type = "object-store"
+		client, err = openstack.NewContainerV1(provider, endpointOpts)
+		if err != nil {
 			return nil, err
 		}
+	} else if err != nil {
+		return nil, err
 	}
 
 	return client, nil
